# Autogenerated by Astropy's setup.py on 2019-10-27 21:59:33 UTC
from __future__ import unicode_literals
import datetime

version = "2.0.16"
githash = "f8b3f30f552ac5566e9d45a3db18dfa34b94469e"


major = 2
minor = 0
bugfix = 16

release = True
timestamp = datetime.datetime(2019, 10, 27, 21, 59, 33)
debug = False

astropy_helpers_version = "2.0.11"

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
